Learn R Programming

ggguitar (version 0.1.1)

chords: A dataset containing chords.

Description

A dataset containing chords, their location on a guitar neck, and the standard fingering used to play them.

Usage

chords

Arguments

Format

A data frame chords: