Learn R Programming

ggguitar (version 0.1.1)

narrow_chord: Narrow (Filter) Chord Selection

Description

This function filters rows in the chord data frame by criteria passed in and accounts for nulls. The nifty bit is - given a full set of chords, you can get chords that use a given fret or frets.

Usage

narrow_chord(chords, value, name)

Arguments

chords
A data frame of chords.
value
The value to be filtered.
name
The name to be filtered.

Value

Returns a data frame of chords.