Learn R Programming

ggguitar (version 0.1.1)

notes_for_frets: This function is similar to chord_for_frets but also handles scales. Unlike chords_for_frets, this function removes NAs. This means there are no muted strings identified if a chord is passed in the frets argument.

Description

This function is similar to chord_for_frets but also handles scales. Unlike chords_for_frets, this function removes NAs. This means there are no muted strings identified if a chord is passed in the frets argument.

Usage

notes_for_frets(frets, tuning = c("e", "a", "d", "g", "b", "e"))

Arguments

frets
A vector representing fret positions.
tuning
A 6 element vector representing notes of open strings.

Value

Returns a vector of note names.

See Also

chord_for_frets

Examples

Run this code
G_M_scale <- c(3, 0, 0, 0, NA, NA,
                        NA, 2, 2, NA, NA, NA,
                        NA, 3, 4, NA, NA, NA)
notes_for_frets(G_M_scale)

Run the code above in your browser using DataLab