Learn R Programming

ggguitar (version 0.1.1)

tablature: Create guitar chord tablature chart.

Description

Create guitar chord tablature chart.

Usage

tablature(name, desc, include_text = TRUE, include_title = TRUE, x_labels = NULL, x_axis_label = "String", dot_labels = NULL, dot_label_size = 2)

Arguments

name
The name of the chord
desc
A vector with 6 elements representing strings. A number indicates the fret and NA indicates a string should not be played.
include_text
Include tick mark labels on x and y axis. Default is TRUE.
include_title
Include the labels on the x and y axis. Default is TRUE.
x_labels
A vector containing x tick mark labels. Default is string numbers.
x_axis_label
The x axis label. Default is String.
dot_labels
Adds labels in place of dots on frets.
dot_label_size
Set the size of labels used in place of dots on frets.

Examples

Run this code
tablature('G Major', c(3, 2, 0, 0, 0, 3))

B_M <- c(NA, 2, 4, 4, 4, 2)
tablature('B Major (bar)', B_M,
           x_labels=c(0,1,3,3,3,1),
           x_axis_label = 'Finger')

tablature('B Major (bar)', B_M,
           dot_labels = c('','B','F#','B','D#','F#'))

Run the code above in your browser using DataLab