notes_for_frets: This function is similar to chord_for_frets but
also handles scales.
Unlike chords_for_frets, this function removes NAs.
This means there are no muted strings identified
if a chord is passed in the frets argument.
Description
This function is similar to chord_for_frets but
also handles scales.
Unlike chords_for_frets, this function removes NAs.
This means there are no muted strings identified
if a chord is passed in the frets argument.